==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/WebGridClipboardEventDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridClipboardEventDetailDescription } from "./WebGridClipboardEventDetailDescription";
/**
 * @hidden
 */
var WebGridClipboardEventDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebGridClipboardEventDetailDescriptionMetadata, _super);
    function WebGridClipboardEventDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGridClipboardEventDetailDescriptionMetadata.b = function (a) {
        if (WebGridClipboardEventDetailDescriptionMetadata.a == null) {
            WebGridClipboardEventDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGridClipboardEventDetailDescriptionMetadata.c(WebGridClipboardEventDetailDescriptionMetadata.a);
        }
        if (a.j(WebGridClipboardEventDetailDescriptionMetadata.a)) {
            return;
        }
        a.y(WebGridClipboardEventDetailDescriptionMetadata.a);
    };
    WebGridClipboardEventDetailDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:GridClipboardEventDetail");
        a.item("__packageNameWC", "String:grids");
        a.item("__isPlainObject", "Boolean");
        a.item("DataRef", "(w:Data,wf:Data)DataRef:object");
        a.item("Cancel", "Boolean");
    };
    WebGridClipboardEventDetailDescriptionMetadata.d = function (a) {
        WebGridClipboardEventDetailDescriptionMetadata.b(a);
        a.aa("WebGridClipboardEventDetail", function () { return new WebGridClipboardEventDetailDescription(); });
        a.z("WebGridClipboardEventDetail", WebGridClipboardEventDetailDescriptionMetadata.a);
    };
    WebGridClipboardEventDetailDescriptionMetadata.$t = markType(WebGridClipboardEventDetailDescriptionMetadata, 'WebGridClipboardEventDetailDescriptionMetadata');
    WebGridClipboardEventDetailDescriptionMetadata.a = null;
    return WebGridClipboardEventDetailDescriptionMetadata;
}(Base));
export { WebGridClipboardEventDetailDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebGridClipboardEventDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridClipboardEventDetailDescription } from "./WebGridClipboardEventDetailDescription";
/**
 * @hidden
 */
var WebGridClipboardEventDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebGridClipboardEventDetailDescriptionMetadata, _super);
    function WebGridClipboardEventDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGridClipboardEventDetailDescriptionMetadata.b = function (a) {
        if (WebGridClipboardEventDetailDescriptionMetadata.a == null) {
            WebGridClipboardEventDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGridClipboardEventDetailDescriptionMetadata.c(WebGridClipboardEventDetailDescriptionMetadata.a);
        }
        if (a.k(WebGridClipboardEventDetailDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebGridClipboardEventDetailDescriptionMetadata.a);
    };
    WebGridClipboardEventDetailDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:GridClipboardEventDetail");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("DataRef", "(w:Data,wf:Data)DataRef:object");
        a.item("Cancel", "Boolean");
    };
    WebGridClipboardEventDetailDescriptionMetadata.d = function (a) {
        WebGridClipboardEventDetailDescriptionMetadata.b(a);
        a.ac("WebGridClipboardEventDetail", function () { return new WebGridClipboardEventDetailDescription(); });
        a.ab("WebGridClipboardEventDetail", WebGridClipboardEventDetailDescriptionMetadata.a);
    };
    WebGridClipboardEventDetailDescriptionMetadata.$t = markType(WebGridClipboardEventDetailDescriptionMetadata, 'WebGridClipboardEventDetailDescriptionMetadata');
    WebGridClipboardEventDetailDescriptionMetadata.a = null;
    return WebGridClipboardEventDetailDescriptionMetadata;
}(Base));
export { WebGridClipboardEventDetailDescriptionMetadata };
